from setuptools import setup

setup(name='rsnd_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['rsnd_distributions'],
      author = 'Roshan Madipalli',
      author_email = 'roshan26102000@gmail.com',
      zip_safe=False)
